import { Construct, Resource } from '@aws-cdk/core';
import { CommonStageOptions, IStage } from '../common';
import { IHttpApi } from './api';
/**
 * Options to create a new stage for an HTTP API.
 */
export interface HttpStageOptions extends CommonStageOptions {
}
/**
 * Properties to initialize an instance of `HttpStage`.
 */
export interface HttpStageProps extends HttpStageOptions {
    /**
     * The HTTP API to which this stage is associated.
     */
    readonly httpApi: IHttpApi;
}
/**
 * Represents a stage where an instance of the API is deployed.
 * @resource AWS::ApiGatewayV2::Stage
 */
export declare class HttpStage extends Resource implements IStage {
    /**
     * Import an existing stage into this CDK app.
     */
    static fromStageName(scope: Construct, id: string, stageName: string): IStage;
    readonly stageName: string;
    private httpApi;
    constructor(scope: Construct, id: string, props: HttpStageProps);
    /**
     * The URL to this stage.
     */
    get url(): string;
}
